.. image:: https://img.shields.io/pypi/v/sstudentt?style=for-the-badge
        :alt: PyPI
        :target: https://pypi.org/project/sstudentt/

.. image:: https://img.shields.io/pypi/status/sstudentt?style=for-the-badge
        :alt: PyPI - Status
        :target: https://pypi.org/project/sstudentt/

.. image:: https://img.shields.io/travis/BerriJ/sstudentt?style=for-the-badge
        :alt: Travis (.com)
        :target: https://travis-ci.com/berrij/sstudentt

.. image:: https://img.shields.io/readthedocs/sstudentt?style=for-the-badge
        :alt: Documentation Status
        :target: https://sstudentt.readthedocs.io/en/latest/usage.html

.. image:: https://img.shields.io/pypi/l/sstudentt?style=for-the-badge
        :alt: PyPI - License
        :target: https://pypi.org/project/sstudentt/

|

================================================================================
A python implementation of the skewed student-t distribution.
================================================================================

This package implements the skewed student-t distribution in python. Parameterized as described in Wurtz et. al (2006) [1]_.
An implementation in R is already existent [2]_.

Features
--------

* Evaluate the density function
* Evaluate the cumulative distribution function
* Evaluate the quantile function
* Generate random numbers

References
----------

.. [1] Wurtz, Y. Chalabi, and L. Luksan. Parameter estimation of arma models with garch/aparch errors. an r and splus software implementation. Journal of Statistical Software, 2006.

.. [2] R Implementation: https://www.gamlss.com/wp-content/uploads/2018/01/DistributionsForModellingLocationScaleandShape.pdf


Licence
-------
Free software: GNU General Public License v3

Documentation
-------------
Documentation: https://sstudentt.readthedocs.io.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
